import Alpine from 'alpinejs'
import { wait } from '@testing-library/dom'

global.MutationObserver = class {
    observe() {}
}

test('x-if', async () => {
    document.body.innerHTML = `
        <div x-data="{ show: false }">
            <button x-on:click="show = ! show"></button>

            <template x-if="show">
                <p></p>
            </template>
        </div>
    `

    Alpine.start()

    expect(document.querySelector('p')).toBeFalsy()

    document.querySelector('button').click()

    await wait(() => { expect(document.querySelector('p')).toBeTruthy() })
})

test('elements inside x-if are still reactive', async () => {
    document.body.innerHTML = `
        <div x-data="{ show: false, foo: 'bar' }">
            <h1 x-on:click="show = ! show"></h1>

            <template x-if="show">
                <h2 @click="foo = 'baz'"></h2>
            </template>

            <span x-text="foo"></span>
        </div>
    `

    Alpine.start()

    expect(document.querySelector('h2')).toBeFalsy()
    expect(document.querySelector('span').innerText).toEqual('bar')

    document.querySelector('h1').click()

    await wait(() => {
        expect(document.querySelector('h2')).toBeTruthy()
    })

    document.querySelector('h2').click()

    await wait(() => {
        expect(document.querySelector('span').innerText).toEqual('baz')
    })
})
